@@ -1,4 +1,4 @@
-`dsbel` <-
+dsbel <-
 function(x){
 # Belief function
 #=========================================================================   
