@@ -1,4 +1,4 @@
-`dsbelpl` <-
+dsbelpl <-
 function(x,a){
 # Belief and Plausibility of an interval
 #=========================================================================   
