@@ -1,4 +1,4 @@
-`dsbelpltests` <-
+dsbelpltests <-
 function(x,a){
 # Belief and Plausibility of a set of points a respective to a BPA x.
 #=========================================================================
