@@ -1,4 +1,4 @@
-`dsmeanvar` <-
+dsmeanvar <-
 function(intervalnumber, mean, var){
 # Generates a BPA enclosing all CDFs with given mean and variance
 #=========================================================================
