@@ -1,4 +1,4 @@
-`dsminmeanmax` <-
+dsminmeanmax <-
 function(intervalnumber,min,mean,max){
 # Generates a BPA enclosing all CDFs with given min, mean and max
 #=========================================================================
