@@ -1,4 +1,4 @@
-`dsminmodemax` <-
+dsminmodemax <-
 function(intervalnumber,min,mode,max){
 # Generates a BPA enclosing all CDFs with given min, mode and max
 #=========================================================================
