@@ -1,4 +1,4 @@
-`dspl` <-
+dspl <-
 function(x){
 # Plausibility function
 #=========================================================================   
