@@ -1,4 +1,4 @@
-`dsstruct` <-
+dsstruct <-
 function(x){
 # geometric mean calculation
 # Returns a new Dempster-Shafer structure
