@@ -1,4 +1,4 @@
-`dswmix` <-
+dswmix <-
 function(...,w=NULL) {
 # Weighted mixture of BPAs "..." with optional weights w
 #=========================================================================
