@@ -1,4 +1,4 @@
-`dsxaveraging` <-
+dsxaveraging <-
 function(...,w=NULL,maxfocals=10000000){
 # XEnveloping of BPAs "..."
 #=========================================================================
