@@ -1,4 +1,4 @@
-`dsxenvelope` <-
+dsxenvelope <-
 function(...,maxfocals=10000000){
 # XEnveloping of BPAs "..." with optional weights w
 #=========================================================================
